@@ -18,7 +18,7 @@ def main():
     maxvar = AR.maxVariance()
 
     grid = Interfaces.TensorflowGrid(model, maxvar[0].name, maxvar[1].name, df, ["Survived"])
-    fig = Graphs.PlotlyGrid(grid, maxvar[0].name, maxvar[1].name)
+    fig, _, _ = Graphs.PlotlyGrid(grid, maxvar[0].name, maxvar[1].name)
     fig.show()
 
     grid = Interfaces.TensorflowGrid(model, 'Parch', 'SibSp', df, ["Survived"])
